@@ -1,8 +1,8 @@
-#
+
 #	$RCSfile: syntax.pl,v $
-#	$Revision: 2.2 $
+#	$Revision: 2.3 $
 #	$Author: ripe-dbm $
-#	$Date: 1996/08/09 12:55:04 $
+#	$Date: 1996/08/14 15:45:49 $
 #
 #       ARGUMENTS:      *ASSOC object
 #       RETURNS:        INTEGER object_status
@@ -311,7 +311,7 @@ sub checksyntax {
 #
 	    }
 	    else {
-	        if ($itmp=~ /^ac|ah|tc|zc|cy|mb|ml$/) {
+	        if ($itmp=~ /^ac|ah|ch|tc|zc|cy|mb|ml$/) {
 		    local($val, $msg) = &dosyntax($itmp, $object{$itmp}, *object);
 		    # print STDERR "checksyntax - before attr: $itmp rtcode: $rtcode val: $val msg: $msg\n" if ($opt_V);
 		    if (defined($val)) {
@@ -711,48 +711,93 @@ sub dosyntax {
 # Try to do something clever with the changed field
 #
 # ch - changed
+# wd - withdrawn
 #
-    if ($key eq "ch") {
+    if ($key=~ /^ch|wd$/) {
     
-       print STDERR "dosyntax - checking ch\n" if $opt_V;
+       print STDERR "dosyntax - checking ch,wd ($key)\n" if $opt_V;
        
-       local($date)="";
+       local($returncode)=$O_OK;
        
-       if ($value=~ / /) {
-          $value=~ s/ +(\S+)$//;
-          $date=$1;
+       local($date);
+       local(@newchanged)=();
+       local(@changedvalues)=split(/\n+/, $value);
+       
+       #
+       # add current date if needed to last specified attribute
+       
+       if ($changedvalues[$#changedvalues]!~ / \d{6,6}$/) {
+          
+          $changedvalues[$#changedvalues].=" ".$DATE;
+          
+          &addwarning(*object, "added current date to ".$ATTL{$key}." field");
+          
+          $returncode=$O_WARNING;
+          
        }
        
-       # print STDERR "*", $date, "*", $value, "\n";
+       #
+       # sort values on date
        
-       if (!(&isemail($value))) {
-          return $O_ERROR, "syntax error in e-mail part of \"$ATTL{$key}\"";
+       @changedvalues=sort sortchangedfield @changedvalues;
+       
+       #print STDERR join("\n", "values:", @changedvalues);
+       
+       foreach $value (@changedvalues) {
+       
+          $date="";
+          
+          if ($value=~ / /) {
+             $value=~ s/ +(\S+)$//;
+             $date=$1;
+          }
+       
+          # print STDERR "*", $date, "*", $value, "\n";
+       
+          if (!(&isemail($value))) {
+             return $O_ERROR, "syntax error in e-mail part of \"$ATTL{$key}\"";
+          }
+
+          if (!$date) {
+	     return $O_ERROR, "No date specified in \"$ATTL{$key}\" attribute";
+          }
+           
+	  if ($date=~ /^(\d\d)(\d\d)(\d\d)$/) {
+	  
+	     #
+	     # 1988 is the start of the world. This is where we test for proper
+	     # date values of YYMMDD
+
+             if ($1<88) {
+	        return $O_ERROR, "date ($date) part of \"$ATTL{$key}\" is older then the database itself!";
+	     }
+
+	     if (($2<1) || ($2>12) || ($3>31) || ($3<1)) {
+	        return $O_ERROR, "date ($date) part of \"$ATTL{$key}\" is not a valid YYMMDD value";
+	     }
+	  
+	  }
+	  else {
+	  
+	     return $O_ERROR, "date part of \"$ATTL{$key}\" not in YYMMDD format";
+	
+	  }
+	  
+	  if ($date>$DATE) {
+	     
+	     &addwarning(*object, "date in \"$ATTL{$key}\" ($date) is in the future - changed to $DATE");
+	     $date=$DATE;
+	     $returncode=$O_WARNING;
+	     
+	  }
+	  
+	  push(@newchanged, $value." ".$date);
+	
        }
+	  
+       $object{$key}=join("\n", @newchanged);
 
-       if (!$date) {
-	    return $O_ERROR, 
-	    "No date specified in \"$ATTL{$key}\" attribute";
-        }
-	if ($date!~ /^(\d\d)(\d\d)(\d\d)$/) {
-	    return $O_ERROR, "date part of \"$ATTL{$key}\" not in YYMMDD format";
-	}
-	# 1988 is the start of the world. This is where we test for proper
-	# date values of YYMMDD
-
-	if (($1 < 88) || ($2 > 12) || ($3 > 31)) {
-	    return $O_ERROR, "date part of \"$ATTL{$key}\" is not a valid YYMMDD value";
-	}
-	
-	if ($date>$DATE) {
-	    $object{$key} =~ s/$date/$DATE/g;
-	    return $O_WARNING,
-	    "date in \"$ATTL{$key}\" ($date) is in the ".
-		"future - changed to $DATE";
-	}
-	
-	$object{$key}=~ s/ +/ /g;
-	
-	return $O_OK;
+       return $returncode;
 	
     }
     
@@ -1752,7 +1797,7 @@ sub dosyntax {
           #
           # check if the ID is not already used
           
-          return $O_ERROR, "error in \"$ATTL{$key}\", auto NIC handle assignment\nidentification code ($1.$2) already used in other object" if ($NICID{$object{"so"}, $1.$2});
+          return $O_ERROR, "error in \"$ATTL{$key}\", auto NIC handle assignment\nidentification code ($1.$2) already used in other object" if ($NICID{$object{"so"}, $prefix});
           
           #
           # find initials if not already specified
@@ -1768,8 +1813,14 @@ sub dosyntax {
              
              $object{$key}=$prefix.$initials;
              
+             #
+             # check if the ID is not already used
+             
              $prefix=~ /\-(\d+)$/;
-             $NICID{$object{"so"}, $1}=1;
+             
+             return $O_ERROR, "error in \"$ATTL{$key}\", auto NIC handle assignment identification code ($1) already used in other object\nplease use another number then $1" if ($NICID{$object{"so"}, $prefix});
+          
+             $NICID{$object{"so"}, $prefix}=1;
              
              return $O_OK;
              
@@ -2170,35 +2221,6 @@ sub dosyntax {
 	return $O_OK;
     }
     
-    
-#
-# wd - withdrawn
-#
-    if ($key eq "wd") {
-    
-       print STDERR "dosyntax - checking wd ($key)\n" if $opt_V; 
-        
-	if ($value !~ /^(\d\d)(\d\d)(\d\d)$/) {
-	    return $O_ERROR, 
-	    "date part of \"$ATTL{$key}\" not in YYMMDD format";
-	}
-	
-	# 1988 is the start of the world. This is where we test for proper
-	# date values of YYMMDD
-
-	if (($1 < 88) || ($2 > 12) || ($3 > 31)) {
-	    return $O_ERROR, 
-	    "date part of \"$ATTL{$key}\" is not a valid YYMMDD value";
-	}
-
-	if ($value gt $DATE) {
-	    return $O_ERROR, 
-	    "date in \"$ATTL{$key}\" ($1$2$3) is in the future";
-	}
-	
-	return $O_OK;
-    }
-
 #
 # These are not checked and not used, just in here for clarity
 #
